import React, { useState } from 'react';
import styled from 'styled-components'
import Grid from '@material-ui/core/Grid';
import Fab from '@material-ui/core/Fab';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import ExpandLessIcon from '@material-ui/icons/ExpandLess';
import TopicCard from './TopicCard.js';

export default function TopicList(props) {
	const [expanded, setExpanded] = useState(false);

	const handleFabClick = () => {
		setExpanded(!expanded);
	}

	return (
		<Wrapper>
			<Title contrast={props.contrast}>Módulos</Title>
			<Grid
				container
				spacing={3}
				justify="center"
				alignItems="center"
			>
				{props.topicos.slice(0, (expanded ? -1 : 5)).map((t, index) => {
					return (
						<Grid item key={index} md={3}>
							<TopicCard contrast={props.contrast} topic={t} colecao_id={props.colecao_id} />
						</Grid>
					);
				})
				}
			</Grid>
			{props.topicos.length > 5 ?
				<Grid container
					direction="column"
					justify="flex-start"
					alignItems="center"
				>
					<Grid item>
						<Fab size="medium" color="secondary" aria-label="edit" onClick={handleFabClick} style={props.contrast === "" ? { marginTop: "1em" } : { backgroundColor: "black", border: "1px solid white", marginTop: "1em" }}>
							{expanded ? <ExpandLessIcon /> : <ExpandMoreIcon />}
						</Fab>
					</Grid>
					<Grid item>
						<FabText contrast={props.contrast}>
							{expanded ? "VER MENOS" : "VER TODOS OS MÓDULOS"}
						</FabText>
					</Grid>
				</Grid>
				: <div></div>
			}
		</Wrapper>
	);
}

const FabText = styled.span`
	color: ${props => props.contrast === "" ? "#666" : "white"};
	font-weight: 900;
	line-height: 2em;
`
const Title = styled.h1`
	font-weight: 100;
	margin-left: 30px;
	color: ${props => props.contrast === "" ? "rgb(102, 102, 102)" : "white"};
`
const Wrapper = styled.div`
		margin-right : auto;
		margin-left : auto;
		margin-bottom: 30px;

		@media screen and (max-width: 768px) {
				width : 100% !important;
		}
		@media screen and (min-width: 992px) {
				width : 770px;
		}
		@media screen and (min-width: 1200px) {
				width : 970px !important;
		}
`
