/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import FormControl from '@material-ui/core/FormControl';
import {StyledFormLabel} from '../StyledComponents.js'
import ListItemText from '@material-ui/core/ListItemText';
import Checkbox from '@material-ui/core/Checkbox';
import MenuItem from '@material-ui/core/MenuItem';
import Select from '@material-ui/core/Select';

export default function Idioma (props) {
    const [chosenLanguage, setChosenLanguage] = useState(props.initialValue ? props.initialValue : [])
    const [ids, setIds] = useState(props.initialIDValue ? props.initialIDValue : [])

    const handleChangeLanguage = (event) => {
        let newLanguage = event.target.value.pop()
        if (!chosenLanguage.some(language => language === newLanguage.name)) {
            setChosenLanguage(chosenLanguage => [...chosenLanguage, newLanguage.name]);
            setIds(ids => [...ids, newLanguage.id])    
        }
        else
        {
            if (chosenLanguage.length > 0) {
                setChosenLanguage(chosenLanguage.filter((language) => {return language !== newLanguage.name}));
                setIds(ids.filter((id) => {return id !== newLanguage.id}))    
            }
        }
    };


    return (
        <FormControl style={{minWidth : "30%"}}>
            <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                <b>Idioma</b><span>*</span>
            </StyledFormLabel>
            <Select
                value={chosenLanguage}
                multiple
                renderValue={(selected) => selected.join(', ')}
                name="Idioma"
                onChange={handleChangeLanguage}
                onBlur={() => {props.onBlurCallback("language_ids", ids, props.draftID)}}
            >
                {
                    props.languages.map( language =>
                        <MenuItem key={language.name} value={language}>
                            <Checkbox checked={chosenLanguage.indexOf(language.name) > -1} />
                            <ListItemText primary={language.name} />
                        </MenuItem>
                    )
                }
            </Select>
        </FormControl>
    )
}
